Tutorial
================================================================================

This section covers the use cases for moban. Please check them out individually.

#. `Jinja2 command line`_
#. `Template inheritance`_
#. `Data override`_
#. `Single command`_
#. `Custom configuration`_
#. `Complex configuration`_
#. `Use custom jinja2 filter test n global`_
#. `Pass a folder full of templates`_
#. `Use pypi package as a moban dependency`_
#. `Use git repository as a moban dependency`_
#. `Use handlebars template with moban`_
#. `Use template engine extensions`_
#. `Any data overrides any data`_
#. `Custom data loader`_
#. `Copy templates as target`_
#. `Group targets by template type`_
#. `Force template type from moban file`_
#. `User defined template types`_
#. `Select a group target to run`_
#. `Template files in a zip or tar`_
#. `Template copying from a zip to a zip`_
#. `Intermediate targets`_
#. `Mobanfile inheritance`_
#. `Files over http(s)`_
#. `Remove intermediate targets`_
   
.. _Jinja2 command line: level-1-jinja2-cli
.. _Template inheritance: level-2-template-inheritance
.. _Data override: level-3-data-override
.. _Single command: level-4-single-command
.. _Custom configuration: level-5-custom-configuration
.. _Complex configuration: level-6-complex-configuration
.. _Use custom jinja2 filter test n global: level-7-use-custom-jinja2-filter-test-n-global
.. _Pass a folder full of templates: level-8-pass-a-folder-full-of-templates
.. _Use pypi package as a moban dependency: level-9-moban-dependency-as-pypi-package
.. _Use git repository as a moban dependency: level-10-moban-dependency-as-git-repo
.. _Use handlebars template with moban: level-11-use-handlebars
.. _Use template engine extensions: level-12-use-template-engine-extensions
.. _Any data overrides any data: level-13-any-data-override-any-data
.. _Custom data loader: level-14-custom-data-loader
.. _Copy templates as target: level-15-copy-templates-as-target
.. _Group targets by template type: level-16-group-targets-using-template-type
.. _Force template type from moban file: level-17-force-template-type-from-moban-file
.. _User defined template types: level-18-user-defined-template-types
.. _Select a group target to run: level-19-moban-a-sub-group-in-targets
.. _Template files in a zip or tar: level-20-templates-configs-in-zip-or-tar
.. _Template copying from a zip to a zip: level-21-copy-templates-into-an-alien-file-system
.. _Intermediate targets: level-22-intermediate-targets
.. _Mobanfile inheritance: level-23-inherit-organisational-moban-file
.. _Files over http(s): level-24-files-over-http
.. _Remove intermediate targets: level-25-delete-intermediate
